BundleScratch

Struct BundleScratch 

pub struct BundleScratch { /* private fields */ }
Enables pushing components to internal scratch space (uses a bump allocator), which can then be written as a dynamic bundle. The contents are cleared after each write and the allocated scratch space is reused across writes.

Also see BundleWriter.

Implementations



impl BundleScratch

pub fn writer<'a>(&'a mut self) -> BundleWriter<'a>

Creates a new BundleWriter using this scratch space. For safety / correctness, this will clear any existing components.

Note that for performance reasons this will not clear the internal allocator. To avoid leaking, make sure every component pushed to the BundleWriter is followed by either a BundleWriter::write or a BundleScratch::manual_drop.

pub fn is_empty(&self) -> bool

Returns true if there are currently no components stored in the scratch space.

pub unsafe fn manual_drop(&mut self, components: &Components)

This will drop all components currently stored in the scratch space. This is generally used to ensure drops occur in error scenarios.

Safety

components must be from the same world as the components that were pushed to this writer.