BundleWriter

Struct BundleWriter 

pub struct BundleWriter<'a>(/* private fields */);
Enables pushing components to the internal BundleScratch, which can then be written as a dynamic bundle.

Components pushed to this writer should either be followed by a BundleWriter::write or a BundleScratch::manual_drop to avoid leaking.

Implementations



impl<'a> BundleWriter<'a>

pub unsafe fn push_component<C>( &mut self, components: &mut ComponentsRegistrator<'_>, component: C, )
where C: Component,

Pushes the given component to the back of the current bundle scratch space. It will register the component in components if it does not already exist.

Safety

components must be from the same world that all previous Self::push_component or Self::push_component_by_id calls were called with, and the next Self::write or Self::write_with_relationship_hook_insert_mode call.

pub unsafe fn push_component_by_id( &mut self, id: ComponentId, component: OwningPtr<'_>, layout: Layout, )

Pushes the given component ptr to the back of the current bundle scratch space.

Safety

components must be from the same world that all previous Self::push_component or Self::push_component_by_id calls were called with, and the next Self::write or Self::write_with_relationship_hook_insert_mode call. component must point to a Component value that matches id. layout must correspond to the layout of the Component type.

pub unsafe fn write(self, entity: &mut EntityWorldMut<'_>)

Writes the current contents of the bundle to the given entity and clears the scratch space.

Runs with RelationshipHookMode::Run by default. Use write_with_relationship_hook_insert_mode if you need more flexibility.

Safety

entity must be from the same world that all Self::push_component or Self::push_component_by_id calls since the last Self::write or Self::write_with_relationship_hook_insert_mode were called with.

pub unsafe fn write_with_relationship_hook_insert_mode( self, entity: &mut EntityWorldMut<'_>, relationship_hook_insert_mode: RelationshipHookMode, )

Writes the current contents of the bundle to the given entity and clears the scratch space.

Also accepts RelationshipHookMode as an argument. Prefer write to this if RelationshipHookMode::Run by default is enough.

Safety

entity must be from the same world that all Self::push_component or Self::push_component_by_id calls since the last Self::write or Self::write_with_relationship_hook_insert_mode were called with.

pub fn is_empty(&self) -> bool

Returns true if there are currently no components.