Struct Bundles
pub struct Bundles { /* private fields */ }Expand description
Metadata for bundles. Stores a BundleInfo for each type of Bundle in a given world.
Implementations
impl Bundles
impl Bundles
pub fn iter(&self) -> impl Iterator<Item = &BundleInfo>
pub fn iter(&self) -> impl Iterator<Item = &BundleInfo>
Iterate over BundleInfo.
pub fn get(&self, bundle_id: BundleId) -> Option<&BundleInfo>
pub fn get(&self, bundle_id: BundleId) -> Option<&BundleInfo>
Gets the metadata associated with a specific type of bundle.
Returns None if the bundle is not registered with the world.