Struct BundleInfo
pub struct BundleInfo { /* private fields */ }Implementations
impl BundleInfo
impl BundleInfo
pub fn explicit_components(&self) -> &[ComponentId]
pub fn explicit_components(&self) -> &[ComponentId]
Returns the ID of each component explicitly defined in this bundle (ex: Required Components are excluded).
For all components contributed by this bundle (including Required Components), see BundleInfo::contributed_components
pub fn required_components(&self) -> &[ComponentId]
pub fn required_components(&self) -> &[ComponentId]
Returns the ID of each Required Component needed by this bundle. This does not include Required Components that are explicitly provided by the bundle.
pub fn contributed_components(&self) -> &[ComponentId]
pub fn contributed_components(&self) -> &[ComponentId]
Returns the ID of each component contributed by this bundle. This includes Required Components.
For only components explicitly defined in this bundle, see BundleInfo::explicit_components
pub fn iter_explicit_components(
&self,
) -> impl Iterator<Item = ComponentId> + Clone
pub fn iter_explicit_components( &self, ) -> impl Iterator<Item = ComponentId> + Clone
Returns an iterator over the ID of each component explicitly defined in this bundle (ex: this excludes Required Components).
To iterate all components contributed by this bundle (including Required Components), see BundleInfo::iter_contributed_components
pub fn iter_contributed_components(
&self,
) -> impl Iterator<Item = ComponentId> + Clone
pub fn iter_contributed_components( &self, ) -> impl Iterator<Item = ComponentId> + Clone
Returns an iterator over the ID of each component contributed by this bundle. This includes Required Components.
To iterate only components explicitly defined in this bundle, see BundleInfo::iter_explicit_components
pub fn iter_required_components(&self) -> impl Iterator<Item = ComponentId>
pub fn iter_required_components(&self) -> impl Iterator<Item = ComponentId>
Returns an iterator over the ID of each Required Component needed by this bundle. This does not include Required Components that are explicitly provided by the bundle.